@@ -487,7 +487,7 @@ event_out:
  * @repair_id	servicelog repair ID
  *
  * Returns :
- *	0 on sucess, !0 on failure
+ *	0 on success, !0 on failure
  */
 static int
 parse_repair_event(int repair_id)
@@ -585,6 +585,8 @@ parse_repair_event(int repair_id)
 	if (rc)
 		log_msg("Unable to disable fault indicator");
 
+	free_fru_loc_code(o_frus);
+	free_fru_loc_code(r_frus);
 	/* free indicator list */
 	free_indicator_list(list);
 
@@ -758,6 +760,14 @@ UI_commit(WINDOW *my_menu_win, MENU *my_menu,
 		if (!strcmp(desc, "loc")) {
 			name = (char *)item_name(items[i]);
 			loc = get_indicator_for_loc_code(ident_list, name);
+			if (!loc) {
+				 if (cur_state[i] == '+') {
+					 cur_state[i] = prev_state[i];
+					 err = 1;
+				 }
+				continue;
+			}
+
 			rc = get_indicator_state(LED_TYPE_IDENT, loc, &ident);
 			if (rc) {
 				if (cur_state[i] == '+') {
@@ -1171,8 +1181,11 @@ main(int argc, char *argv[])
 	char	*next_char;
 
 	program_name = argv[0];
-	if (probe_indicator() != 0)
-		return 1;
+	if (probe_indicator() != 0) {
+		fprintf(stderr,
+			"%s is not supported on this platform\n", argv[0]);
+		return 0;
+	}
 
 	opterr = 0;
 	while ((c = getopt_long(argc, argv, LP_DIAG_ARGS,
