@@ -19,7 +19,7 @@ int parse_hm_scn(struct opal_hm_scn **r_hm,
 		return -EINVAL;
 	}
 
-	*r_hm = (struct opal_hm_scn *) malloc(sizeof(struct opal_hm_scn));
+	*r_hm = malloc(sizeof(struct opal_hm_scn));
 	if(!*r_hm)
 		return -ENOMEM;
 	hm = *r_hm;
@@ -37,5 +37,6 @@ int print_hm_scn(const struct opal_hm_scn *hm)
 	print_opal_v6_hdr(hm->v6hdr);
 	print_mtms_struct(hm->mtms);
 
+	print_bar();
 	return 0;
 }
