@@ -55,6 +55,7 @@
 #define POLL_TIMEOUT	1000 /* In milliseconds */
 
 #define DEFAULT_SYSFS_PATH		"/sys"
+#define DEFAULT_DUMP_PATH		"firmware/opal/dump"
 #define DEFAULT_OUTPUT_DIR		"/var/log/opal-elog"
 #define DEFAULT_EXTRACT_DUMP_CMD	"/usr/sbin/extract_opal_dump"
 #define DEFAULT_EXTRACT_DUMP_FNAME "extract_opal_dump"
@@ -67,7 +68,7 @@
 /**
  * ELOG retention policy
  *
- * Retain logs upto 30 days with max 1000 logs.
+ * Retain logs up to 30 days with max 1000 logs.
  */
 #define DEFAULT_MAX_ELOGS		1000
 #define DEFAULT_MAX_DAYS		30
@@ -80,7 +81,7 @@
 
 #define ELOG_DATE_OFFSET	0x8
 #define ELOG_TIME_OFFSET	0xc
-#define ELOG_ID_OFFESET		0x2c
+#define ELOG_ID_OFFSET		0x2c
 #define ELOG_SEVERITY_OFFSET	0x3a
 #define ELOG_SUBSYSTEM_OFFSET	0x38
 #define ELOG_ACTION_OFFSET	0x42
@@ -284,7 +285,7 @@ static int parse_log(char *buffer, size_t bufsz)
 		return -1;
 	}
 
-	logid = be32toh(*(uint32_t*)(buffer + ELOG_ID_OFFESET));
+	logid = be32toh(*(uint32_t*)(buffer + ELOG_ID_OFFSET));
 
 	memcpy(src, (buffer + ELOG_SRC_OFFSET), ELOG_SRC_SIZE);
 	src[ELOG_SRC_SIZE] = '\0';
@@ -340,6 +341,7 @@ static void check_platform_dump(const char *extract_opal_dump_cmd,
 	if (fork_pid == -1) {
 		syslog(LOG_NOTICE, "Couldn't fork() (%d:%s)\n",
 		       errno, strerror(errno));
+		return;
 	} else if (fork_pid == 0) {
 		/* Child */
 		char *args[] = { (char *)extract_opal_dump_cmd, "-s", (char *)sysfs_path,
@@ -689,6 +691,7 @@ int main(int argc, char *argv[])
 	int opt;
 	char sysfs_path[PATH_MAX];
 	char elog_path[PATH_MAX];
+	char dump_path[PATH_MAX];
 	char *extract_opal_dump_cmd = NULL;
 
 	int log_options;
@@ -773,6 +776,14 @@ int main(int argc, char *argv[])
 	 */
 	extract_opal_dump_cmd = validate_extract_opal_dump(opt_extract_opal_dump_cmd);
 
+	/* Validate dump sysfs path */
+	snprintf(dump_path, sizeof(dump_path),
+		 "%s/%s", opt_sysfs, DEFAULT_DUMP_PATH);
+	if (access(dump_path, R_OK)) {
+		free(extract_opal_dump_cmd);
+		extract_opal_dump_cmd = NULL;
+	}
+
 	/* Use PATH_MAX but admit that it may be insufficient */
 	rc = snprintf(sysfs_path, sizeof(sysfs_path), "%s/firmware/opal",
 		      opt_sysfs);
